.. -*- coding: utf-8 -*-

Changes
-------

0.1 (2016-03-21)
~~~~~~~~~~~~~~~~

- First cut of the features.

0.2 (2016-03-29)
~~~~~~~~~~~~~~~~

- use arrow functions to retain ``this`` were possible.
- translate ``async/await``.
- refactoring of the ``for`` loops.
- add ability to subtranslate pieces of Python code or objects. Used
  to template the creation of ``Exception`` sublasses.
- add support for param defaults and keyword arguments.
- updated documentation.
